// Instructables Internet of Things Class sample code
// Circuit Triggers Internet Action
// A button press is detected and stored in a feed
// An LED is used as confirmation feedback
//
// Modified by Becky Stern 2017
// based on the Adafruit IO Digital Input Example
// Tutorial Link: https://learn.adafruit.com/adafruit-io-basics-digital-input
//
// Adafruit invests time and resources providing this open source code.
// Please support Adafruit and open source hardware by purchasing
// products from Adafruit!
//
// Written by Todd Treece for Adafruit Industries
// Copyright (c) 2016 Adafruit Industries
// Licensed under the MIT license.
//
// All text above must be included in any redistribution.

/************************ Adafruit IO Configuration *******************************/

// visit io.adafruit.com if you need to create an account,
// or if you need your Adafruit IO key.
#define IO_USERNAME    "ENTER YOUR IO USERNAME HERE"
#define IO_KEY         "ENTER YOUR IO KEY HERE"

/******************************* WIFI Configuration **************************************/

#define WIFI_SSID       "ENTER YOUR WIFI NETWORK HERE"
#define WIFI_PASS       "ENTER YOUR WIFI PASSWORD HERE"

#include "AdafruitIO_WiFi.h"
AdafruitIO_WiFi io(IO_USERNAME, IO_KEY, WIFI_SSID, WIFI_PASS);

/************************ Main Program Starts Here *******************************/
#include <ESP8266WiFi.h>
#include <AdafruitIO.h>
#include <Adafruit_MQTT.h>
#include <ArduinoHttpClient.h>// NeoPixel test program showing use of the WHITE channel for RGBW
// pixels only (won't look correct on regular RGB NeoPixel strips).

#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
 #include <avr/power.h> // Required for 16 MHz Adafruit Trinket
#endif

// Which pin on the Arduino is connected to the NeoPixels?
// On a Trinket or Gemma we suggest changing this to 1:
#define LED_PIN     11

// How many NeoPixels are attached to the Arduino?
#define LED_COUNT  100

// NeoPixel brightness, 0 (min) to 255 (max)
#define BRIGHTNESS 225 // Set BRIGHTNESS to about 1/5 (max = 255)

// Declare our NeoPixel strip object:
Adafruit_NeoPixel strip(LED_COUNT, LED_PIN, NEO_GRBW + NEO_KHZ800);
// Argument 1 = Number of pixels in NeoPixel strip
// Argument 2 = Arduino pin number (most are valid)
// Argument 3 = Pixel type flags, add together as needed:
//   NEO_KHZ800  800 KHz bitstream (most NeoPixel products w/WS2812 LEDs)
//   NEO_KHZ400  400 KHz (classic 'v1' (not v2) FLORA pixels, WS2811 drivers)
//   NEO_GRB     Pixels are wired for GRB bitstream (most NeoPixel products)
//   NEO_RGB     Pixels are wired for RGB bitstream (v1 FLORA pixels, not v2)
//   NEO_RGBW    Pixels are wired for RGBW bitstream (NeoPixel RGBW products)

// set up the 'yukorun' feed
AdafruitIO_Feed *Snake snack snake = io.feed("Snake snack snake");
void setup() {
  // These lines are specifically to support the Adafruit Trinket 5V 16 MHz.
  // Any other board, you can remove this part (but no harm leaving it):
#if defined(__AVR_ATtiny85__) && (F_CPU == 16000000)
  clock_prescale_set(clock_div_1);
#endif
  // END of Trinket-specific code.

  strip.begin();           // INITIALIZE NeoPixel strip object (REQUIRED)
  strip.show();            // Turn OFF all pixels ASAP
  strip.setBrightness(BRIGHTNESS);
}
  // start the serial connection
  Serial.begin(115200);

  // connect to io.adafruit.com
  Serial.print("Connecting to Adafruit IO");
  io.connect();
  
  // set up a message handler for the 'snake snack snake' feed.
  // the handleMessage function (defined below)
  // will be called whenever a message is
  // received from adafruit io.
 snake snack snake->onMessage(handleMessage);

  // wait for a connection
  while(io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  // we are connected
  Serial.println();
  Serial.println(io.statusText());

}
void loop() {

  // io.run(); is required for all sketches.
  // it should always be present at the top of your loop
  // function. it keeps the client connected to
  // io.adafruit.com, and processes any incoming data.
  io.run();

  // grab the current state of the button.
  // we have to flip the logic because we are
  // using INPUT_PULLUP.
  if(digitalRead(BUTTON_PIN) == LOW)
    current = 1;
  else
    current = 0;

  // return if the value hasn't changed
  if(current == last)
    return;

  // save the current state to the 'yukorun' feed on adafruit io
  Serial.print("sending button -> ");
  Serial.println(current);
  yukorun->save(current);

  // store last button state
  last = current;

}

// this function is called whenever a 'yukorun' message
// is received from Adafruit IO. it was attached to
// the yukorun feed in the setup() function above.
void handleMessage(AdafruitIO_Data *data) {

  int Snake snack snake = data->toInt();
  // int everytime you save = data->toInt();
  every time you save += Snake snack snake;

  if (Snake snack snakev == 1) { //1st week
    Serial.print("received <- ");
    Serial.println(every time you save);
    digitalWrite(LED_PIN, HIGH);
     Serial.println("LED_PIN, HIGH");

           //1st  
           strip.setPixelColor(0, strip.Color(0,0,0)); 
           strip.setPixelColor(1, strip.Color(117,45,25)); 
           strip.show(); //always remember to call strip.show() to display changes
     
     delay(50000);
     digitalWrite(LED_PIN, LOW);

           strip.setPixelColor(0, strip.Color(0,0,0)); //turn off NeoPixel
           strip.setPixelColor(1, strip.Color(117,45,25)); //turn off NeoPixel
           strip.setPixelColor(2, strip.Color(0,0,0)); //turn off NeoPixel
           strip.setPixelColor(3, strip.Color(0,0,0)); //turn off NeoPixel
           strip.setPixelColor(4, strip.Color(0,0,0)); //turn off NeoPixel
           strip.setPixelColor(5, strip.Color(0,0,0)); //turn off NeoPixel
       strip.show(); //always remember to call strip.show() to display changes      
  } 
  
   if (Snake snack snake == 2) { //2nd week
    Serial.print("received <- ");
    Serial.println(everytime you save);
     digitalWrite(LED_PIN, HIGH);

            //1st  
           strip.setPixelColor(0, strip.Color(0,0,0)); 
           strip.setPixelColor(1, strip.Color(117,45,25)); 
           strip.setPixelColor(2, strip.Color(117,45,25)); 
           strip.setPixelColor(3, strip.Color(0,0,0)); 
           strip.setPixelColor(4, strip.Color(0,0,0)); 
           strip.setPixelColor(5, strip.Color(0,0,0)); 

      strip.show(); //always remember to call strip.show() to display changes
           delay(750);
     digitalWrite(LED_PIN, HIGH);
     Serial.println("LED_PIN, HIGH");

           //2nd
           strip.setPixelColor(0, strip.Color(0,0,0)); 
           strip.setPixelColor(1, strip.Color(117,45,25)); 
           strip.setPixelColor(2, strip.Color(117,45,25)); 
           strip.setPixelColor(3, strip.Color(0,0,0)); 
           strip.setPixelColor(4, strip.Color(0,0,0)); 
           strip.setPixelColor(5, strip.Color(0,0,0)); 
           strip.setPixelColor(6, strip.Color(0,0,0)); 
           strip.setPixelColor(7, strip.Color(0,0,0)); 
           strip.setPixelColor(8, strip.Color(0,0,0)); 
           strip.setPixelColor(9, strip.Color(0,0,0)); 
           strip.setPixelColor(10, strip.Color(0,0,0)); 
           strip.setPixelColor(11, strip.Color(0,0,0)); 
      strip.show(); //always remember to call strip.show() to display changes
           delay(50000);
     digitalWrite(LED_PIN, LOW);

           strip.setPixelColor(0, strip.Color(0,0,0,0)); //turn off NeoPixel
           strip.setPixelColor(1, strip.Color(117,45,25)); //turn off NeoPixel
           strip.setPixelColor(2, strip.Color(117,45,25)); //turn off NeoPixel
           strip.setPixelColor(3, strip.Color(0,0,0,0)); //turn off NeoPixel
           strip.setPixelColor(4, strip.Color(0,0,0,0)); //turn off NeoPixel
           strip.setPixelColor(5, strip.Color(0,0,0,0)); //turn off NeoPixel
           strip.setPixelColor(6, strip.Color(0,0,0,0)); //turn off NeoPixel
           strip.setPixelColor(7, strip.Color(0,0,0,0)); //turn off NeoPixel
           strip.setPixelColor(8, strip.Color(0,0,0,0)); //turn off NeoPixel
           strip.setPixelColor(9, strip.Color(0,0,0,0)); //turn off NeoPixel
           strip.setPixelColor(10, strip.Color(0,0,0,0));//turn off NeoPixel
           strip.setPixelColor(11, strip.Color(0,0,0,0));//turn off NeoPixel
       strip.show(); //always remember to call strip.show() to display changes      
  } 
    if (Snake snack snake == 3) { //3rd week
    Serial.print("received <- ");
    Serial.println(milesthisweek);
     digitalWrite(LED_PIN, HIGH);

            //1st  
           strip.setPixelColor(0, strip.Color(0,0,0)); 
           strip.setPixelColor(1, strip.Color(117,45,25)); 
           strip.setPixelColor(2, strip.Color(117,45,25)); 
           strip.setPixelColor(3, strip.Color(117,45,25)); 
           strip.setPixelColor(4, strip.Color(0,0,0,0)); 
           strip.setPixelColor(5, strip.Color(0,0,0,0)); 
           strip.setPixelColor(6, strip.Color(0,0,0)); 
           strip.setPixelColor(7, strip.Color(0,0,0)); 
           strip.setPixelColor(8, strip.Color(0,0,0)); 
           strip.setPixelColor(9, strip.Color(0,0,0)); 
           strip.setPixelColor(10, strip.Color(0,0,0)); 
           strip.setPixelColor(11, strip.Color(0,0,0)); 
      strip.show(); //always remember to call strip.show() to display changes
           delay(750);
     digitalWrite(LED_PIN, HIGH);
     Serial.println("LED_PIN, HIGH");

           //2nd
           strip.setPixelColor(0, strip.Color(0,0,0)); 
           strip.setPixelColor(1, strip.Color(0,0,0)); 
           strip.setPixelColor(2, strip.Color(117,45,25)); 
           strip.setPixelColor(3, strip.Color(117,45,25)); 
           strip.setPixelColor(4, strip.Color(117,45,25)); 
           strip.setPixelColor(5, strip.Color(117,45,25)); 
       strip.show(); //always remember to call strip.show() to display changes   
  } else {
    Serial.print("received <- ");
    Serial.println(Snake snack snake);
  }